==> login_firebase-0.0.2.tar.gz: lib/presentation/widgets/single/SignUpWidget.dart <==
import 'package:flutter/cupertino.dart';
import 'package:login_firebase/business/bloc/SignUpBloc.dart';
import 'package:login_firebase/business/dto/ModSignUpDTO.dart';
import 'package:login_firebase/common/ModErrorCodes.dart';
import 'package:login_firebase/common/ModLogger.dart';
import 'package:login_firebase/models/ModResourceResult.dart';
import 'package:login_firebase/models/ThirdPartyErrorModel.dart';
import 'package:login_firebase/models/ThirdPartySessionModel.dart';
import 'package:login_firebase/presentation/widgets/IForm.dart';
import 'package:login_firebase/presentation/widgets/base/ModBaseStatelessWidgetWithBloc.dart';
import 'package:login_firebase/presentation/widgets/convenient/ModLoadingWidget.dart';


const String TAG = "SignUpWidget";

//ignore: must_be_immutable
class SignUpWidget extends ModBaseStatelessWidgetWithBloc<SignUpBloc, ThirdPartySessionModel> {
  final Widget child;
  final Function(ThirdPartySessionModel?) onSessionSuccess;
  final Function(int) onSessionError;
  final Function() onReset;


  SignUpWidget({
    required this.child,
    required this.onSessionSuccess,
    required this.onSessionError,
    required this.onReset,
    Key? key}) :
        super(key: key) {

    if (this.child is IForm) {
      (this.child as IForm).setListener(onChildValidated);
    } else {
      ModLogger.e(tag: TAG, msg: "Unable to set custom signup");
    }
  }

  @override
  Widget buildErrorState(BuildContext context, ThirdPartyErrorModel? error) {
    this.onSessionError(error!.code);

    return this.child;
  }

  @override
  Widget buildInitialState(BuildContext context) {
    return this.child;
  }

  @override
  Widget buildLoadingState(BuildContext context) {
    return Stack(
      children: [
        this.child,
        ModLoadingWidget()
      ],
    );
  }

  @override
  Widget buildSuccessState(BuildContext context, ThirdPartySessionModel? data) {
    if (data!.validate()) {
      this.onSessionSuccess(data);
    } else {
      this.onSessionError(ModErrorCodes.SIGNUP);
    }

    return this.child;
  }

  @override
  void initBloc(BuildContext context) {
    this.bloc = SignUpBloc();
  }

  void onChildValidated(String mail, String pass) {
    this._call(mail, pass);
  }

  void _call(String mail, String pass) {
    this.bloc!.processData(ModResourceResult(state: ResourceState.LOADING, data: null, error: null));
    this.bloc!.performOperation(ModSignUpDTO(mail: mail, pass: pass, name: ""));
  }
}

==> login_firebase-0.0.4.tar.gz: lib/presentation/widgets/single/SignUpWidget.dart <==
import 'package:flutter/cupertino.dart';
import 'package:login_firebase/business/bloc/SignUpBloc.dart';
import 'package:login_firebase/business/dto/ModSignUpDTO.dart';
import 'package:login_firebase/common/ModErrorCodes.dart';
import 'package:login_firebase/common/ModLogger.dart';
import 'package:login_firebase/models/ModResourceResult.dart';
import 'package:login_firebase/models/ThirdPartyErrorModel.dart';
import 'package:login_firebase/models/ThirdPartySessionModel.dart';
import 'package:login_firebase/presentation/widgets/IForm.dart';
import 'package:login_firebase/presentation/widgets/base/ModBaseStatelessWidgetWithBloc.dart';
import 'package:login_firebase/presentation/widgets/convenient/ModLoadingWidget.dart';


const String TAG = "SignUpWidget";

//ignore: must_be_immutable
class SignUpWidget extends ModBaseStatelessWidgetWithBloc<SignUpBloc, ThirdPartySessionModel> {
  final Widget child;
  final Function(ThirdPartySessionModel?) onSessionSuccess;
  final Function(int) onSessionError;
  final Function() onReset;


  SignUpWidget({
    required this.child,
    required this.onSessionSuccess,
    required this.onSessionError,
    required this.onReset,
    super.key}) {

    if (child is IForm) {
      (child as IForm).setListener(onChildValidated);
    } else {
      ModLogger.e(tag: TAG, msg: "Unable to set custom signup");
    }
  }

  @override
  Widget buildErrorState(BuildContext context, ThirdPartyErrorModel? error) {
    onSessionError(error!.code);

    return child;
  }

  @override
  Widget buildInitialState(BuildContext context) {
    return child;
  }

  @override
  Widget buildLoadingState(BuildContext context) {
    return Stack(
      children: [
        child,
        const ModLoadingWidget()
      ],
    );
  }

  @override
  Widget buildSuccessState(BuildContext context, ThirdPartySessionModel? data) {
    if (data!.validate()) {
      onSessionSuccess(data);
    } else {
      onSessionError(ModErrorCodes.SIGNUP);
    }

    return child;
  }

  @override
  void initBloc(BuildContext context) {
    bloc = SignUpBloc();
  }

  void onChildValidated(String mail, String pass) {
    _call(mail, pass);
  }

  void _call(String mail, String pass) {
    bloc!.processData(ModResourceResult(state: ResourceState.LOADING, data: null, error: null));
    bloc!.performOperation(ModSignUpDTO(mail: mail, pass: pass, name: ""));
  }
}
